/*
 * In this module we are going to implement commands dealing with the ABB.
 */

#include <sys/types.h>
#include <stdio.h>
#include <string.h>
#include <strings.h>
#include <stdlib.h>
#include "../pktmux.h"
#include "../limits.h"
#include "localtypes.h"
#include "etm.h"

extern u_char rvi_msg[];
extern int rvi_msg_len;

void
cmd_abbr(argc, argv)
	char **argv;
{
	u32 page, reg;
	u_char cmdpkt[5];

	page = strtoul(argv[1], 0, 0);
	reg = strtoul(argv[2], 0, 0);
	if (page > 1 || reg > 31) {
		printf("error: argument(s) out of range\n");
		return;
	}
	cmdpkt[1] = ETM_CORE;
	cmdpkt[2] = TMCORE_OPC_CODEC_RD;
	cmdpkt[3] = page << 5 | reg;
	send_etm_cmd(cmdpkt, 3);
}

void
abbr_response()
{
	unsigned pg, reg, val;
	char buf[80];

	if (rvi_msg[3]) {
		print_etm_pkt_raw("abbr error");
		return;
	}
	if (rvi_msg_len != 9) {
		print_etm_pkt_raw("abbr malformed resp");
		return;
	}
	pg = rvi_msg[5] >> 5;
	reg = rvi_msg[5] & 0x1F;
	val = rvi_msg[6] | rvi_msg[7] << 8;
	sprintf(buf, "abbr %u %u: %03X", pg, reg, val);
	async_msg_output(buf);
}

void
cmd_abbw(argc, argv)
	char **argv;
{
	u32 page, reg, val;
	u_char cmdpkt[7];

	page = strtoul(argv[1], 0, 0);
	reg = strtoul(argv[2], 0, 0);
	val = strtoul(argv[3], 0, 16);
	if (page > 1 || reg > 31 || val > 0x3FF) {
		printf("error: argument(s) out of range\n");
		return;
	}
	cmdpkt[1] = ETM_CORE;
	cmdpkt[2] = TMCORE_OPC_CODEC_WR;
	cmdpkt[3] = page << 5 | reg;
	cmdpkt[4] = val;
	cmdpkt[5] = val >> 8;
	send_etm_cmd(cmdpkt, 5);
}

void
abbw_response()
{
	unsigned pg, reg;
	char buf[80];

	if (rvi_msg[3]) {
		print_etm_pkt_raw("abbw error");
		return;
	}
	if (rvi_msg_len != 7) {
		print_etm_pkt_raw("abbw malformed resp");
		return;
	}
	pg = rvi_msg[5] >> 5;
	reg = rvi_msg[5] & 0x1F;
	sprintf(buf, "abbw %u %u OK", pg, reg);
	async_msg_output(buf);
}
