/*
 * Here we sort out incoming packets from the target relayed via rvinterf.
 */

#include <sys/types.h>
#include <stdio.h>
#include <string.h>
#include <strings.h>
#include <stdlib.h>
#include "../pktmux.h"
#include "../limits.h"
#include "../localsock.h"
#include "localtypes.h"
#include "etm.h"

extern u_char rvi_msg[];
extern int rvi_msg_len;

void
safe_print_trace(src, srclen, dest)
	u_char *src;
	char *dest;
{
	int i, c;
	char *dp;

	dp = dest;
	for (i = 0; i < srclen; i++) {
		c = src[i];
		if (c & 0x80) {
			*dp++ = 'M';
			*dp++ = '-';
			c &= 0x7F;
		}
		if (c < 0x20) {
			*dp++ = '^';
			*dp++ = c + '@';
		} else if (c == 0x7F) {
			*dp++ = '^';
			*dp++ = '?';
		} else
			*dp++ = c;
	}
	*dp = '\0';
}

static void
handle_useid_0()
{
	char buf[MAX_PKT_FROM_TARGET*4];

	if (strncmp(rvi_msg + 7, "RVT: Lost Message", 17))
		return;
	safe_print_trace(rvi_msg + 7, rvi_msg_len - 7, buf);
	async_msg_output(buf);
}

static void
print_etm_trace()
{
	char buf[MAX_PKT_FROM_TARGET*4];

	strcpy(buf, "ETM Tr: ");
	safe_print_trace(rvi_msg + 7, rvi_msg_len - 7, buf + 9);
	async_msg_output(buf);
}

static void
process_rvt()
{
	u32 useid;

	if (rvi_msg_len < 7) {
		tty_cleanup();
		fprintf(stderr, "Error: rvinterf sent us an invalid RVT msg\n");
		exit(1);
	}
	useid = rvi_msg[2] << 24 | rvi_msg[3] << 16 | rvi_msg[4] << 8
		| rvi_msg[5];
	switch (useid) {
	case 0:
		handle_useid_0();
		return;
	case ETM_USE_ID:
		print_etm_trace();
		return;
	default:
		tty_cleanup();
		fprintf(stderr, "unexpected fwd of USEID %08X from rvinterf\n",
			useid);
		exit(1);
	}
}

void
process_pkt_from_target()
{
	switch (rvi_msg[1]) {
	case RVT_RV_HEADER:
		process_rvt();
		return;
	case RVT_TM_HEADER:
		etm_packet_rx();
		return;
	default:
		tty_cleanup();
		fprintf(stderr, "unexpected fwd of MUX %02X from rvinterf\n",
			rvi_msg[1]);
		exit(1);
	}
}
